-- xyzspain

Kverneland5090MT = {};

function Kverneland5090MT.prerequisitesPresent(specializations)
     return SpecializationUtil.hasSpecialization(Attachable, specializations);
end;

function Kverneland5090MT:load(xmlFile)

 self.groundReferenceThreshold = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.groundReferenceNode#threshold"), 0.5);
    self.groundReferenceNodeArea1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.groundReferenceNodeArea1#index"));
    if self.groundReferenceNodeArea1 == nil then
        self.groundReferenceNodeArea1 = self.components[1].node;
    end;
	self.groundReferenceNodeArea2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.groundReferenceNodeArea2#index"));
    if self.groundReferenceNodeArea2 == nil then
        self.groundReferenceNodeArea2 = self.components[1].node;
    end;
----------------------------------
	-- desplazamiento de conjuntos
	self.setHydraulicDirection = SpecializationUtil.callSpecializationsFunction("setHydraulicDirection");
	
	local hydraulicsCount = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.hydraulics#count"), 0);	
	self.hydraulics = {};	
	for i=1, hydraulicsCount do
		local hydraulicName = string.format("vehicle.hydraulics.hydraulic%d", i);		
		self.hydraulics[i] = {};		
		self.hydraulics[i].node = Utils.indexToObject(self.components, getXMLString(xmlFile, hydraulicName .. "#index"));
		self.hydraulics[i].punch = Utils.indexToObject(self.components, getXMLString(xmlFile, hydraulicName .. "#punch"));
		self.hydraulics[i].translationPunch = Utils.indexToObject(self.components, getXMLString(xmlFile, hydraulicName .. "#punchFixpoint"));
		self.hydraulics[i].fixPoint = Utils.indexToObject(self.components, getXMLString(xmlFile, hydraulicName .. "#fixpoint"));	
		local ax, ay, az;		
		if self.hydraulics[i].punch ~= nil then
			ax, ay, az = getWorldTranslation(self.hydraulics[i].punch);
		else
			ax, ay, az = getWorldTranslation(self.hydraulics[i].node);
		end;
		local bx, by, bz = getWorldTranslation(self.hydraulics[i].translationPunch);		
		self.hydraulics[i].punchDistance = Utils.vector3Length(ax-bx, ay-by, az-bz);
		self.hydraulics[i].doScale = Utils.getNoNil(getXMLBool(xmlFile, hydraulicName .. "#doScale"), false);
	end;
	-------------------
	
		 local rotationNode3 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.rotation3#index"));
    if rotationNode3 ~= nil then
        self.rotation3 = {};
        self.rotation3.node = rotationNode3;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotation3#minRot"));
        self.rotation3.minRot = {};
        self.rotation3.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotation3.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotation3.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotation3#maxRot"));
        self.rotation3.maxRot = {};
        self.rotation3.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotation3.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotation3.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

         self.rotation3.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotation3#rotTime"), 2)*1000;
      
    end;
			 local rotationNode4 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.rotation4#index"));
    if rotationNode4 ~= nil then
        self.rotation4 = {};
        self.rotation4.node = rotationNode4;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotation4#minRot"));
        self.rotation4.minRot = {};
        self.rotation4.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotation4.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotation4.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotation4#maxRot"));
        self.rotation4.maxRot = {};
        self.rotation4.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotation4.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotation4.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

         self.rotation4.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotation4#rotTime"), 2)*1000;
      
    end;
	
  self.discos = {};

    local psFile = getXMLString(xmlFile, "vehicle.discos.disco(1)#index");
    if psFile ~= nil then
        local i=0;
        while true do
            local baseName = string.format("vehicle.discos.disco(%d)", i);
            local node = {};
            node.index = getXMLString(xmlFile, baseName.. "#index");
            node.direction = getXMLInt(xmlFile, baseName.. "#direction");
            if node.index == nil then
                break;
            end;
            node.index = Utils.indexToObject(self.components, node.index);
            if node ~= nil then
                table.insert(self.discos, node);
            end;
            i = i+1;
        end;
    end;
	
	 self.acondicionadores = {};

    local psFile = getXMLString(xmlFile, "vehicle.acondicionadores.acondicionador(1)#index");
    if psFile ~= nil then
        local i=0;
        while true do
            local baseName = string.format("vehicle.acondicionadores.acondicionador(%d)", i);
            local node = {};
            node.index = getXMLString(xmlFile, baseName.. "#index");
            node.direction = getXMLInt(xmlFile, baseName.. "#direction");
            if node.index == nil then
                break;
            end;
            node.index = Utils.indexToObject(self.components, node.index);
            if node ~= nil then
                table.insert(self.acondicionadores, node);
            end;
            i = i+1;
        end;
    end;
	--------------------
	
	

		-- animacion
	self.anim = SpecializationUtil.callSpecializationsFunction("anim");
	self.Go = {}; 
	self.Done = {};
	self.charId = {};
	self.clipIndex = {};
	self.CheckDone = {};
	self.animParts = {}
	self.Activated = {};
	------
	self.startpoint = {};
	self.loopCheck = {};
	self.Speed = {};
	
	
	local count = getXMLInt(xmlFile, "vehicle.animParts#count");
	local part = self.animParts;
    for i=1, count do
		part[i] = {};
		local partname = string.format("vehicle.animParts.part".."%d", i);
	    local nameR = getXMLString(xmlFile, partname.."#name");
		self.charId[nameR] = Utils.indexToObject(self.components, getXMLString(xmlFile, partname.."#rootNode"));
		self.clipIndex[nameR] = getXMLString(xmlFile, partname.."#animationClip");
		self.CheckDone[nameR] = false;
		self.Activated[nameR] = false;
		-----
		self.startpoint[nameR] = Utils.getNoNil(getXMLFloat(xmlFile, partname.."#startpoint"),0.0);
		local charId = getAnimCharacterSet(self.charId[nameR]);
		local clipIndex = getAnimClipIndex(charId, self.clipIndex[nameR]);
		assignAnimTrackClip(charId , 0, clipIndex);
		setAnimTrackTime(charId, 0, self.startpoint[nameR]);
		enableAnimTrack(charId, 0);
		disableAnimTrack(charId, 0);
		self.loopCheck[nameR] = false;
		self.Speed[nameR] = 1.0;
		
		
		
	end; 	
	
	self.AllActivated = SpecializationUtil.callSpecializationsFunction("AllActivated");
	------
		--------------------------
	 local rearMowerSound = getXMLString(xmlFile, "vehicle.rearMowerSound#file");
    if rearMowerSound ~= nil and rearMowerSound ~= "" then
        rearMowerSound = Utils.getFilename(rearMowerSound, self.baseDirectory); 
        self.rearMowerSound = createSample("rearMowerSound");
        self.rearMowerSoundEnabled = false;
        loadSample(self.rearMowerSound, rearMowerSound, false);
        self.rearMowerSoundPitchOffset = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.rearMowerSound#pitchOffset"), 1);
        self.rearMowerSoundVolume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.rearMowerSound#volume"), 1);
    end;
	
		---libertad bloques
	self.setJointRotLimit = SpecializationUtil.callSpecializationsFunction("setJointRotLimit");
	self.firstDo = {};
	self.arm = {};
	
	------------------------------
		--- ajuste orientacion attach
		self.doJointOrientation = false;
		self.attacherJointCopy = nil;
		self.updateJoint = false;
	local count = getXMLInt(xmlFile, "vehicle.rotationParts#count");
	if count ~= nil then
		self.rotationParts = {}
		local rotationPart = self.rotationParts;
		for i=1, count do
			local varName = string.format("rotationPart" .. "%d", i);
			rotationPart[varName] = {};
			local rotationPartname = string.format("vehicle.rotationParts.rotationPart" .. "%d", i);
			rotationPart[varName].index = Utils.indexToObject(self.components, getXMLString(xmlFile, rotationPartname .. "#index"));
			local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, rotationPartname .. "#minRot"));
			rotationPart[varName].minRot = {};
			rotationPart[varName].minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
			rotationPart[varName].minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
			rotationPart[varName].minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));
			local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, rotationPartname .. "#maxRot"));
			rotationPart[varName].maxRot = {};
			rotationPart[varName].maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
			rotationPart[varName].maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
			rotationPart[varName].maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

			rotationPart[varName].rotTime = Utils.getNoNil(getXMLInt(xmlFile, rotationPartname .. "#rotTime"), 2)*1000;	
			rotationPart[varName].touchRotLimit = Utils.getNoNil(getXMLInt(xmlFile, rotationPartname .. "#touchRotLimit"), 1)/1000;	
		end;
	end;
 
		--------------------------
	self.wheatParticleSystemsLeft = {};
    local i = 0;
    while true do
        local namei = string.format("vehicle.wheatParticleSystemsLeft.wheatParticleSystemsLeft(%d)", i);
		local nodei = Utils.indexToObject(self.components, getXMLString(xmlFile, namei .. "#index"));
		if nodei == nil then
			break;
		end; 
        Utils.loadParticleSystem(xmlFile, self.wheatParticleSystemsLeft, namei, nodei, false, nil, self.baseDirectory)	
			
		i = i +1;		
    end;
	
	self.barleyParticleSystemsLeft = {};
    local i = 0;
    while true do
        local namei = string.format("vehicle.barleyParticleSystemsLeft.barleyParticleSystemsLeft(%d)", i);
		local nodei = Utils.indexToObject(self.components, getXMLString(xmlFile, namei .. "#index"));
		if nodei == nil then
			break;
		end; 
        Utils.loadParticleSystem(xmlFile, self.barleyParticleSystemsLeft, namei, nodei, false, nil, self.baseDirectory)	
		
		i = i +1;		
    end;
	
	self.grassParticleSystemsLeft = {};
    local i = 0;
    while true do
        local namei = string.format("vehicle.grassParticleSystemsLeft.grassParticleSystemsLeft(%d)", i);
		local nodei = Utils.indexToObject(self.components, getXMLString(xmlFile, namei .. "#index"));
		if nodei == nil then
			break;
		end; 
        Utils.loadParticleSystem(xmlFile, self.grassParticleSystemsLeft, namei, nodei, false, nil, self.baseDirectory)		
		
		i = i +1;		
    end;
	
	self.wheatParticleSystemsRight = {};
    local i = 0;
    while true do
        local namei = string.format("vehicle.wheatParticleSystemsRight.wheatParticleSystemsRight(%d)", i);
		local nodei = Utils.indexToObject(self.components, getXMLString(xmlFile, namei .. "#index"));
		if nodei == nil then
			break;
		end; 
        Utils.loadParticleSystem(xmlFile, self.wheatParticleSystemsRight, namei, nodei, false, nil, self.baseDirectory)	
			
		i = i +1;		
    end;
	
	self.barleyParticleSystemsRight = {};
    local i = 0;
    while true do
        local namei = string.format("vehicle.barleyParticleSystemsRight.barleyParticleSystemsRight(%d)", i);
		local nodei = Utils.indexToObject(self.components, getXMLString(xmlFile, namei .. "#index"));
		if nodei == nil then
			break;
		end; 
        Utils.loadParticleSystem(xmlFile, self.barleyParticleSystemsRight, namei, nodei, false, nil, self.baseDirectory)	
		
		i = i +1;		
    end;
	
	self.grassParticleSystemsRight = {};
    local i = 0;
    while true do
        local namei = string.format("vehicle.grassParticleSystemsRight.grassParticleSystemsRight(%d)", i);
		local nodei = Utils.indexToObject(self.components, getXMLString(xmlFile, namei .. "#index"));
		if nodei == nil then
			break;
		end; 
        Utils.loadParticleSystem(xmlFile, self.grassParticleSystemsRight, namei, nodei, false, nil, self.baseDirectory)		
		
		i = i +1;		
    end;
		
	-------------------------
	
---------------------
local sound1 = getXMLString(xmlFile, "vehicle.sound1#file");
    if sound1 ~= nil and sound1 ~= "" then
        sound1 = Utils.getFilename(sound1, self.baseDirectory); 
        self.sound1 = createSample("sound1");
        self.sound1Enabled = false;
        loadSample(self.sound1, sound1, false);
        self.sound1PitchOffset = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.sound1#pitchOffset"), 1);
        self.sound1Volume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.sound1#volume"), 1);
    end;
	local sound2 = getXMLString(xmlFile, "vehicle.sound2#file");
    if sound2 ~= nil and sound2 ~= "" then
        sound2 = Utils.getFilename(sound2, self.baseDirectory); 
        self.sound2 = createSample("sound2");
        self.sound2Enabled = false;
        loadSample(self.sound2, sound2, false);
        self.sound2PitchOffset = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.sound2#pitchOffset"), 1);
        self.sound2Volume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.sound2#volume"), 1);
    end;
	local sound3 = getXMLString(xmlFile, "vehicle.sound3#file");
    if sound3 ~= nil and sound3 ~= "" then
        sound3 = Utils.getFilename(sound3, self.baseDirectory); 
        self.sound3 = createSample("sound3");
        self.sound3Enabled = false;
        loadSample(self.sound3, sound3, false);
        self.sound3PitchOffset = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.sound3#pitchOffset"), 1);
        self.sound3Volume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.sound3#volume"), 1);
    end;
	local sound4 = getXMLString(xmlFile, "vehicle.sound4#file");
    if sound4 ~= nil and sound4 ~= "" then
        sound4 = Utils.getFilename(sound4, self.baseDirectory); 
        self.sound4 = createSample("sound4");
        self.sound4Enabled = false;
        loadSample(self.sound4, sound4, false);
        self.sound4PitchOffset = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.sound4#pitchOffset"), 1);
        self.sound4Volume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.sound4#volume"), 1);
    end;
 ---------flashlights
	self.FlashLightLeft = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.indexl#index"));
    self.FlashLightRight = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.indexr#index"));	 
	
    self.flashLightLeftActive = false;
    self.flashLightRightActive = false;
    self.flash = false;
    self.flashRight = false;
    self.flashLeft = false;
    self.delayOnLeft = 0;
    self.delayOffLeft = 0;
    self.delayOnRight = 0;
    self.delayOffRight = 0;
    self.delayOn = 0;
    self.delayOff = 0;
   
    turnSoundFile = Utils.getFilename("turn.wav", self.baseDirectory);
    self.turnSoundId = createSample("turnSound");
    loadSample(self.turnSoundId, turnSoundFile, false);
	-------------------
	Kverneland5090MT.sowingId = g_currentMission.sowingChannel;
	
	self.vehicleType = getXMLString(xmlFile, "vehicle#type");
	self.free = true;
	self.isOpen=true;
	self.openFinished=true;
	 self.isTurnedOn = false;
    self.wasToFast = false;
	self.AIon=false;
	
	self.okLeft=true;
	self.okRight=true;
	self.rotation3Max=false;
	self.rotation4Max=false;
end;
function Kverneland5090MT:delete()
    if self.rearMowerSound ~= nil then
        delete(self.rearMowerSound);
    end;
	if self.sound1 ~= nil then
        delete(self.sound1);
    end;
if self.sound3 ~= nil then
        delete(self.sound3);
    end;
if self.sound2 ~= nil then
        delete(self.sound2);
    end;
if self.sound4 ~= nil then
        delete(self.sound4);
    end;
	
end;

function Kverneland5090MT:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Kverneland5090MT:keyEvent(unicode, sym, modifier, isDown)
		self.on=true;
---flashlights
	
	if isDown and sym == Input.KEY_KP_1 then
		self.flashLeft = not self.flashLeft;
		self.delayOnLeft = 10;
		self.flashRight = false;
		self.flash = false;
		self.flashLightRightActive = false;
	end;

	if isDown and sym == Input.KEY_KP_3 then
		self.flashRight = not self.flashRight;
		self.delayOnRight = 10;
		self.flashLeft = false;
		self.flash = false;
		self.flashLightLeftActive = false;
	end;
	if isDown and sym == Input.KEY_KP_2 then
		self.flash = not self.flash;
		self.flashRight = false;
		self.flashLeft = false;
		self.delayOn = 20;
		self.flashLightRightActive = false;
		self.flashLightLeftActive = false;
	end;
	-----------
end;

function Kverneland5090MT:update(dt)
if self.Go.Lift ~= nil and self.Done.Lift ~= false then
			self:anim("Lift", false); 
end;
if self.Go.Suports ~= nil and self.Done.Suports ~= false then
			self:anim("Suports", false); 
end;
self.wasToFast = false;		

		if self.doJointOrientation and self.attacherVehicle ~= nil then
		for k,v in pairs(self.attacherVehicle.attachedImplements) do
			if v.object == self then
				local joint = self.attacherVehicle.attacherJoints[v.jointDescIndex];
				self.attacherJointCopy = {};
				self.attacherJointCopy.joint = joint;	
				self.attacherJointCopy.minRotCopy = joint.minRot;
				self.attacherJointCopy.maxRotCopy = joint.maxRot;
				joint.minRot = joint.maxRot;
			end;
		end;
		self.doJointOrientation = false;
	end;

	
	
if self:getIsActive() then 
	
		
	
if self.attacherVehicle then	
	
	
	--- flashLights

		if self.FlashLightLeft ~= nil then
				if self.flashLightLeftActive then
					setVisibility(self.FlashLightLeft, self.flashLightLeftActive);
					
			else
					setVisibility(self.FlashLightLeft, self.flashLightLeftActive);
			end;
			end;

		if self.FlashLightRight ~= nil then
				if self.FlashLightRightActive then
					setVisibility(self.FlashLightRight, self.flashLightRightActive);
			else
					setVisibility(self.FlashLightRight, self.flashLightRightActive);
			end;
			end;

		if self.flashLeft then
			if self.delayOnLeft >= -1 then
				self.delayOnLeft = self.delayOnLeft -dt;
			end;
			if not self.flashLightLeftActive then
				if self.delayOnLeft < 0 then
					self.delayOffLeft = 500;
					self.flashLightLeftActive = true;
					playSample(self.turnSoundId, 1, 0.7, 0);
				end;
			end;
			if self.delayOffLeft >= 0 then
				self.delayOffLeft = self.delayOffLeft -dt;
			end;
			if self.flashLightLeftActive then
				if self.delayOffLeft < 0 then
					self.delayOnLeft = 500;
					self.flashLightLeftActive = false;
				end;
			end;
		end;

		if self.flashRight then
			if self.delayOnRight >= 0 then
				self.delayOnRight = self.delayOnRight -dt;
			end;
			if not self.flashLightRightActive then
				if self.delayOnRight < 0 then
					self.delayOffRight = 500;
					self.flashLightRightActive = true;
					playSample(self.turnSoundId, 1, 0.7, 0);
				end;
			end;
			if self.delayOffRight >= 0 then
				self.delayOffRight = self.delayOffRight -dt;
			end;
			if self.flashLightRightActive then
				if self.delayOffRight < 0 then
					self.delayOnRight = 500;
					self.flashLightRightActive = false;
				end;
			end;
		end;

		if self.flash then
		
			if self.delayOn >= 0 then
				self.delayOn = self.delayOn -dt;
			end;
			if not self.flashLightRightActive then
				if self.delayOn < 0 then
					self.delayOff = 500;
					
					self.flashLightRightActive = true;
					self.flashLightLeftActive = true;
					playSample(self.turnSoundId, 1, 0.7, 0);
					
				end;
			end;
			if self.delayOff >= 0 then
				self.delayOff = self.delayOff -dt;
			end;
			if self.flashLightRightActive then
				if self.delayOff < 0 then
					self.delayOn = 500;
				
					self.flashLightLeftActive = false;
					self.flashLightRightActive = false;
				end;
			end;
			else
			
		end;

		if not self.flashLeft and not self.flashRight then
			if not self.flash then
				self.flashLightRightActive = false;
				self.flashLightLeftActive = false;
			end;
		end;
			
		if not self.flash and not self.flashLeft then
			if not self.flashRight then
				self.flashLightRightActive = false;
			end;
		end;

		if not self.flash and not self.flashRight then
			if not self.flashLeft then
				self.flashLightLeftActive = false;
			end;
		end;
		
		-------------------
		self.isModifierActive = false;
		local hydraulicMovingDirection = 0;
	
		   if InputBinding.hasEvent (InputBinding.SWITCH_IMPLEMENT) then 
			self.on=not self.on;
			end;
		if self.on then
		
		---- ajuste attach
		
				if InputBinding.isPressed(InputBinding.LOWER_HYDRAULIC) then
					hydraulicMovingDirection = -1;
				elseif InputBinding.isPressed(InputBinding.LIFT_HYDRAULIC) then
					hydraulicMovingDirection = 1;
				end;
			
	
			local jointDesc = self.attacherJointCopy.joint;
			setJointRotationLimit(jointDesc.jointIndex, 2, true, math.rad(0), math.rad(0));
			jointDesc.moveDown = false;
			self.movingDirection = 1;
			if hydraulicMovingDirection ~= 0 then				
				if jointDesc.rotationNode ~= nil then
					local x, y, z = getRotation(jointDesc.rotationNode);
					local rot = {x,y,z};
					local newRot = Utils.getMovedLimitedValues(rot, self.attacherJointCopy.maxRotCopy, self.attacherJointCopy.minRotCopy, 3, jointDesc.moveTime, dt, hydraulicMovingDirection == 1);
					setRotation(jointDesc.rotationNode, unpack(newRot));
					jointDesc.maxRot = newRot;
					jointDesc.minRot = newRot;
					setJointFrame(jointDesc.jointIndex, 0, jointDesc.jointTransform);
				end;
			end;
			if InputBinding.hasEvent (InputBinding.TURN_UP) then
				self.down=not self.down;
			
			end;
			if InputBinding.hasEvent (InputBinding.TURN_DOWN) then
				self.up=not self.up;
			
			end;
			-------
			if not self.isTurnedOn then
				if InputBinding.hasEvent (InputBinding.IMPLEMENT_EXTRA2) then
				self.isOpen=not self.isOpen;
				self.isTurnedOn =false;
				end;
			end;
			
			if self.isOpen then
			
				self.Go.Lift=false;
				self.Done.Lift= true;
					if not self.sound1Enabled  and not self.AIon and self:getIsActiveForSound() then  ---activar sound1 cierre
					setSamplePitch(self.sound1, self.sound1PitchOffset);
					playSample(self.sound1, 0, self.sound1Volume, 0);
					self.sound1Enabled = true;
					end;
			elseif not self.isOpen then
			
				self.openFinished=false;
				self.free = false;
				self.rotation3Max=false;
				self.rotation4Max=false;
				self.Go.Lift=true;
				self.Done.Lift= true;
				
					if not self.sound2Enabled  and not self.AIon and self:getIsActiveForSound() then  ---activar sound2
					setSamplePitch(self.sound2, self.sound2PitchOffset);
					playSample(self.sound2, 0, self.sound2Volume, 0);
					self.sound2Enabled = true;
					end;

			end;	
				self.Speed.Lift= 0.8; 
				self.Speed.Suports= 1;
	
		
	if (self.CheckDone["Lift"] == false) and self.Activated["Lift"] == true  then
		if self.sound1Enabled then ---desactivar sound1
			stopSample(self.sound1);
			self.sound1Enabled = false;
		end;
		self.openFinished=true;
		self.free = true;
		if InputBinding.hasEvent (InputBinding.MOWER_LEFT) then
				self.okLeft=not self.okLeft;
		end;	
		if InputBinding.hasEvent (InputBinding.MOWER_RIGHT) then
			self.okRight=not self.okRight;
		end;	
		if InputBinding.hasEvent(InputBinding.LOWER_IMPLEMENT) then
			if  self.okLeft then
				self.rotation3Max=not self.rotation3Max;
			end;
			if   self.okRight then
				self.rotation4Max=not self.rotation4Max;
			end;	
		end;	
		
			if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA) then
			self.isTurnedOn = not self.isTurnedOn;
			end;
		
	end;	
	
	if (self.CheckDone["Lift"] == true) and self.Activated["Lift"] == false then

		if self.sound2Enabled then ---desactivar sound2
		stopSample(self.sound2);
		self.sound2Enabled = false;
		end;
			
		
	end;	
	

		if not self.rotation3Max then	
			if not self.sound3Enabled  and not self.AIon and self:getIsActiveForSound() then ---activar sound3
				setSamplePitch(self.sound3, self.sound3PitchOffset);
				playSample(self.sound3, 0, self.sound3Volume, 0);
				self.sound3Enabled = true;
				end;
			local x, y, z = getRotation(self.rotation3.node);
			
			if z < Utils.degToRad(1)  then
				if self.sound3Enabled then ---desactivar sound3
				stopSample(self.sound3);
				self.sound3Enabled = false;
				end;
				
			end;
			
		else 
			if not self.sound3Enabled  and not self.AIon and self:getIsActiveForSound() then  ---activar sound3
				setSamplePitch(self.sound3, self.sound3PitchOffset);
				playSample(self.sound3, 0, self.sound3Volume, 0);
				self.sound3Enabled = true;
				end;
				local x, y, z = getRotation(self.rotation3.node);
			if z > Utils.degToRad(39)  then
				if self.sound3Enabled then ---desactivar sound3
				stopSample(self.sound3);
				self.sound3Enabled = false;
				end;
				
			end;
			
		end;
	
		if not self.rotation4Max then	
			if not self.sound4Enabled  and not self.AIon and self:getIsActiveForSound() then  ---activar sound4
				setSamplePitch(self.sound4, self.sound4PitchOffset);
				playSample(self.sound4, 0, self.sound4Volume, 0);
				self.sound4Enabled = true;
				end;
			local x, y, z = getRotation(self.rotation4.node);
			
			if z > Utils.degToRad(-1)  then
				if self.sound4Enabled then ---desactivar sound4
				stopSample(self.sound4);
				self.sound4Enabled = false;
				end;
				
			end;
			
		else 
				if not self.sound4Enabled  and not self.AIon and self:getIsActiveForSound() then  ---activar sound4
				setSamplePitch(self.sound4, self.sound4PitchOffset);
				playSample(self.sound4, 0, self.sound4Volume, 0);
				self.sound4Enabled = true;
				end;
				local x, y, z = getRotation(self.rotation4.node);
			if z < Utils.degToRad(-39)  then
				if self.sound4Enabled then ---desactivar sound4
				stopSample(self.sound4);
				self.sound4Enabled = false;
				end;
				
			end;
			
		end;

		
	end;---on	
		
	
       
	  if self.isTurnedOn then
		 for i=1, table.getn(self.discos) do
                local disco = self.discos[i].index;
                local discoRot = (-0.7*self.discos[i].direction)*dt;
                rotate(disco,0 , discoRot, 0);
            end;
			  for i=1, table.getn(self.acondicionadores) do
                local acondicionador = self.acondicionadores[i].index;
                local acondicionadorRot = (-0.6*self.acondicionadores[i].direction)*dt;
                rotate(acondicionador, acondicionadorRot, 0, 0 );
            end;
			---areas start
			local toFast = self:doCheckSpeedLimit() and self.lastSpeed*3600 > 30;
		if not toFast then
			---area1
			 local x,y,z = getWorldTranslation(self.groundReferenceNodeArea1);
            local terrainHeightArea1 = getTerrainHeightAtWorldPos(g_currentMission.terrainRootNode, x, 0, z);
            if terrainHeightArea1+self.groundReferenceThreshold >= y then
				
					local area = 0;
					local areaWheat = 0;
					local areaBarley = 0;
                    for k, cuttingArea in pairs(self.cuttingAreas) do
						if k == 1  then
							local x,y,z = getWorldTranslation(self.cuttingAreas[k].start);
							local x1,y1,z1 = getWorldTranslation(self.cuttingAreas[k].width);
							local x2,y2,z2 = getWorldTranslation(self.cuttingAreas[k].height);
							area = Utils.updateMeadowArea(x, z, x1, z1, x2, z2);
							
							areaWheat = Utils.cutFruitArea(FruitUtil.FRUITTYPE_WHEAT, x, z, x1, z1, x2, z2);
							areaBarley = Utils.cutFruitArea(FruitUtil.FRUITTYPE_BARLEY, x, z, x1, z1, x2, z2);
						elseif k== 3 then
							local x,y,z = getWorldTranslation(self.cuttingAreas[k].start);
							local x1,y1,z1 = getWorldTranslation(self.cuttingAreas[k].width);
							local x2,y2,z2 = getWorldTranslation(self.cuttingAreas[k].height);
							if area> 0 then
								local old, total = Utils.getFruitCutLongArea(FruitUtil.FRUITTYPE_DRYGRASS, x, z, x1, z1, x2, z2);							
								local value = 1+math.floor(old / total + 0.7);
								value = math.min(value, g_currentMission.maxWindrowValue);
								Utils.updateFruitCutLongArea(FruitUtil.FRUITTYPE_GRASS, x, z, x1, z1, x2, z2, value, true, false);
								Utils.setEmittingState(self.grassParticleSystemsLeft, true)
							else
								Utils.setEmittingState(self.grassParticleSystemsLeft, false)
							end;
							if areaWheat > 0 then							
								local old, total = Utils.getFruitWindrowArea(FruitUtil.FRUITTYPE_WHEAT, x, z, x1, z1, x2, z2);
								local value = 1+math.floor(old / total + 0.7);
								value = math.min(value, g_currentMission.maxWindrowValue);
								Utils.updateFruitWindrowArea(FruitUtil.FRUITTYPE_WHEAT, x, z, x1, z1, x2, z2, value, true);	
								Utils.setEmittingState(self.wheatParticleSystemsLeft, true)
							else
								Utils.setEmittingState(self.wheatParticleSystemsLeft, false)
							end;
							if areaBarley > 0 then
								local old, total = Utils.getFruitWindrowArea(FruitUtil.FRUITTYPE_BARLEY, x, z, x1, z1, x2, z2);
								local value = 1+math.floor(old / total + 0.7);
								value = math.min(value, g_currentMission.maxWindrowValue);
								Utils.updateFruitWindrowArea(FruitUtil.FRUITTYPE_BARLEY, x, z, x1, z1, x2, z2, value, true);	
								Utils.setEmittingState(self.barleysParticleSystemsLeft, true)
							else
								Utils.setEmittingState(self.barleysParticleSystemsLeft, false)
							end;
						elseif k== 5  then
							local x,y,z = getWorldTranslation(self.cuttingAreas[k].start);
							local x1,y1,z1 = getWorldTranslation(self.cuttingAreas[k].width);
							local x2,y2,z2 = getWorldTranslation(self.cuttingAreas[k].height);
							local dx, dz, dwidthX, dwidthZ, dheightX, dheightZ = Utils.getXZWidthAndHeight(detailId, x, z, x1, z1, x2, z2);
							Utils.updateDestroyCommonArea(x, z, x1, z1, x2, z2)
							setDensityParallelogram(Kverneland5090MT.detailId, dx, dz, dwidthX, dwidthZ, dheightX, dheightZ, Kverneland5090MT.sowingId, 1, 0)
						end;
                    end;
              
            end;
			----area2
			 local x,y,z = getWorldTranslation(self.groundReferenceNodeArea2);
            local terrainHeightArea2 = getTerrainHeightAtWorldPos(g_currentMission.terrainRootNode, x, 0, z);
            if terrainHeightArea2+self.groundReferenceThreshold >= y then
				
					local area = 0;
					local areaWheat = 0;
					local areaBarley = 0;
                    for k, cuttingArea in pairs(self.cuttingAreas) do
						if k == 2  then
							local x,y,z = getWorldTranslation(self.cuttingAreas[k].start);
							local x1,y1,z1 = getWorldTranslation(self.cuttingAreas[k].width);
							local x2,y2,z2 = getWorldTranslation(self.cuttingAreas[k].height);
							area = Utils.updateMeadowArea(x, z, x1, z1, x2, z2);
							
							areaWheat = Utils.cutFruitArea(FruitUtil.FRUITTYPE_WHEAT, x, z, x1, z1, x2, z2);
							areaBarley = Utils.cutFruitArea(FruitUtil.FRUITTYPE_BARLEY, x, z, x1, z1, x2, z2);
						elseif k== 4 then
							local x,y,z = getWorldTranslation(self.cuttingAreas[k].start);
							local x1,y1,z1 = getWorldTranslation(self.cuttingAreas[k].width);
							local x2,y2,z2 = getWorldTranslation(self.cuttingAreas[k].height);
							if area > 0 then
								local old, total = Utils.getFruitCutLongArea(FruitUtil.FRUITTYPE_DRYGRASS, x, z, x1, z1, x2, z2);							
								local value = 1+math.floor(old / total + 0.7);
								value = math.min(value, g_currentMission.maxWindrowValue);
								Utils.updateFruitCutLongArea(FruitUtil.FRUITTYPE_GRASS, x, z, x1, z1, x2, z2, value, true, false);	
								Utils.setEmittingState(self.grassParticleSystemsRight, true)
							else
								Utils.setEmittingState(self.grassParticleSystemsRight, false)
							
							end;
							if areaWheat > 0 then							
								local old, total = Utils.getFruitWindrowArea(FruitUtil.FRUITTYPE_WHEAT, x, z, x1, z1, x2, z2);
								local value = 1+math.floor(old / total + 0.7);
								value = math.min(value, g_currentMission.maxWindrowValue);
								Utils.updateFruitWindrowArea(FruitUtil.FRUITTYPE_WHEAT, x, z, x1, z1, x2, z2, value, true);	
								Utils.setEmittingState(self.wheatParticleSystemsRight, true)
							else
								Utils.setEmittingState(self.wheatParticleSystemsRight, false)
							end;
							if areaBarley > 0 then
								local old, total = Utils.getFruitWindrowArea(FruitUtil.FRUITTYPE_BARLEY, x, z, x1, z1, x2, z2);
								local value = 1+math.floor(old / total + 0.7);
								value = math.min(value, g_currentMission.maxWindrowValue);
								Utils.updateFruitWindrowArea(FruitUtil.FRUITTYPE_BARLEY, x, z, x1, z1, x2, z2, value, true);	
									Utils.setEmittingState(self.barleysParticleSystemsRight, true)
							else
								Utils.setEmittingState(self.barleysParticleSystemsRight, false)
								
							end;
							elseif k==8 then
							local x,y,z = getWorldTranslation(self.cuttingAreas[k].start);
							local x1,y1,z1 = getWorldTranslation(self.cuttingAreas[k].width);
							local x2,y2,z2 = getWorldTranslation(self.cuttingAreas[k].height);
							local dx, dz, dwidthX, dwidthZ, dheightX, dheightZ = Utils.getXZWidthAndHeight(detailId, x, z, x1, z1, x2, z2);
							Utils.updateDestroyCommonArea(x, z, x1, z1, x2, z2)
							setDensityParallelogram(Kverneland5090MT.detailId, dx, dz, dwidthX, dwidthZ, dheightX, dheightZ, Kverneland5090MT.sowingId, 1, 0)
						end;
                    end;
              
				end;
		 else  --- to fast
							Utils.setEmittingState(self.grassParticleSystemsLeft, false)
							Utils.setEmittingState(self.wheatParticleSystemsLeft, false)
							Utils.setEmittingState(self.barleysParticleSystemsLeft, false)			
							Utils.setEmittingState(self.grassParticleSystemsRight, false)
							Utils.setEmittingState(self.wheatParticleSystemsRight, false)
							Utils.setEmittingState(self.barleysParticleSystemsRight, false)			
			end;
		self.wasToFast = toFast;
			---end areas
          if not self.rearMowerSoundEnabled and self:getIsActiveForSound() then
                setSamplePitch(self.rearMowerSound, self.rearMowerSoundPitchOffset);
                playSample(self.rearMowerSound, 0, self.rearMowerSoundVolume, 0);
                self.rearMowerSoundEnabled = true;
            end;
        else ---not turnedOn
							Utils.setEmittingState(self.grassParticleSystemsLeft, false)
							Utils.setEmittingState(self.wheatParticleSystemsLeft, false)
							Utils.setEmittingState(self.barleysParticleSystemsLeft, false)						
							Utils.setEmittingState(self.grassParticleSystemsRight, false)
							Utils.setEmittingState(self.wheatParticleSystemsRight, false)
							Utils.setEmittingState(self.barleysParticleSystemsRight, false)			
            if self.rearMowerSoundEnabled then
                stopSample(self.rearMowerSound);
                self.rearMowerSoundEnabled = false;
            end;
				

        end;--turnedon
	end; ---attacher
end; ----active
	
	if self.rotation3Max ~= nil then
        local x, y, z = getRotation(self.rotation3.node);
        local rot = {x,y,z};
        local newRot = Utils.getMovedLimitedValues(rot, self.rotation3.maxRot, self.rotation3.minRot, 3, self.rotation3.rotTime, dt, not self.rotation3Max);
        setRotation(self.rotation3.node, unpack(newRot));
    end;	
	if self.rotation4Max ~= nil then
        local x, y, z = getRotation(self.rotation4.node);
        local rot = {x,y,z};
        local newRot = Utils.getMovedLimitedValues(rot, self.rotation4.maxRot, self.rotation4.minRot, 3, self.rotation4.rotTime, dt, not self.rotation4Max);
        setRotation(self.rotation4.node, unpack(newRot));
    end;

	 if self.down then
			local rotationPart = self.rotationParts.rotationPart1;
			local rot = {getRotation(rotationPart.index)};
			local newRot = Utils.getMovedLimitedValues(rot, rotationPart.maxRot, rotationPart.minRot, 3, rotationPart.rotTime, dt, true);
			setRotation(rotationPart.index, unpack(newRot));
	    end;		
		if self.up then
			local rotationPart = self.rotationParts.rotationPart1;
			local rot = {getRotation(rotationPart.index)};
			local newRot = Utils.getMovedLimitedValues(rot, rotationPart.maxRot, rotationPart.minRot, 3, rotationPart.rotTime, dt, false);
			setRotation(rotationPart.index, unpack(newRot));
	    end;  			
	
	--- asignacion de libertad ejes de rotacion segun condiciones de emsamblage  0 x, 2 y ,1 z 
	
	
	
	
	self:setJointRotLimit(self.componentJoints[3],20, 0, 500, self.free == true, 0,dt);	
	self:setJointRotLimit(self.componentJoints[6],15, 0, 500, self.free == true, 2,dt);	
	self:setJointRotLimit(self.componentJoints[7],15, 0, 500,self.free == true, 2,dt);				
			
		
	
	
	
	
	local joint = self.componentJoints[1];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[2];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[3];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[4];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[5];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[6];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[7];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[8];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[9];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[10];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[11];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[12];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[13];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			local joint = self.componentJoints[14];
		setJointFrame(joint.jointIndex, 0,joint.jointNode);
			self:setHydraulicDirection();
		
		
end;



function Kverneland5090MT:draw()
   if self.attacherVehicle  then
		g_currentMission:addExtraPrintText(g_i18n:getText(self.vehicleType..".4"));
	
		if self.openFinished then
	
		g_currentMission:addHelpButtonText(string.format(g_i18n:getText(self.vehicleType..".2"), self.typeDesc), InputBinding.LOWER_IMPLEMENT);
		end;
	
	
		 if self.isTurnedOn then
        g_currentMission:addHelpButtonText(string.format(g_i18n:getText("turn_off_OBJECT"), self.typeDesc), InputBinding.IMPLEMENT_EXTRA);
		
    else
        g_currentMission:addHelpButtonText(string.format(g_i18n:getText("turn_on_OBJECT"), self.typeDesc), InputBinding.IMPLEMENT_EXTRA);
		g_currentMission:addHelpButtonText(string.format(g_i18n:getText(self.vehicleType..".1"), self.typeDesc), InputBinding.IMPLEMENT_EXTRA2);
    end;

end;

   
end;
function Kverneland5090MT:onAttach(attacherVehicle)
	self.doJointOrientation = true;	
	setJointRotationLimit(self.componentJoints[1].jointIndex, 1, true, math.rad(0), math.rad(0));
	setJointRotationLimit(self.componentJoints[1].jointIndex, 2, true, math.rad(0), math.rad(0));
	self.on=false;
	self.isTurnedOn = false;
	self.Go.Suports=true;
	self.Done.Suports= true;
self.free = true;
end;
function Kverneland5090MT:onDetach()
	self.isTurnedOn = false;
	self.Go.Suports=false;
	self.Done.Suports= true;
	self.rotation2Max = false;
	self.rotation3Max = false;
	self.rotation4Max = false;
	self.Go.Lift=false;
	self.Done.Lift= true;
	self.on=false;
	self.free = true;
    if self.deactivateOnDetach then
        Kverneland5090MT.onDeactivate(self);
    else
        Kverneland5090MT.onDeactivateSounds(self)
    end;
	if self.attacherJointCopy ~= nil then
		local jointDesc = self.attacherJointCopy.joint;
		jointDesc.maxRot = self.attacherJointCopy.maxRotCopy;
		jointDesc.minRot = self.attacherJointCopy.minRotCopy;
	end;
	setJointRotationLimit(self.componentJoints[1].jointIndex, 1, true, math.rad(0), math.rad(0));
	setJointRotationLimit(self.componentJoints[1].jointIndex, 2, true, math.rad(0), math.rad(0));
	
	self.flashLightRightActive = false;
	self.flashLightLeftActive = false;
	setVisibility(self.FlashLightRight, false);
	setVisibility(self.FlashLightLeft, false);
end;

function Kverneland5090MT:onLeave()
    if self.deactivateOnLeave then
        Kverneland5090MT.onDeactivate(self);
    else
        Kverneland5090MT.onDeactivateSounds(self)
    end;
end;

function Kverneland5090MT:onDeactivate()
    Kverneland5090MT.onDeactivateSounds(self)

    self.isTurnedOn = false;
	Utils.setEmittingState(self.grassParticleSystemsLeft, false)
	Utils.setEmittingState(self.wheatParticleSystemsLeft, false)
	Utils.setEmittingState(self.barleysParticleSystemsLeft, false)
	Utils.setEmittingState(self.grassParticleSystemsRight, false)
	Utils.setEmittingState(self.wheatParticleSystemsRight, false)
	Utils.setEmittingState(self.barleysParticleSystemsRight, false)						
end;

function Kverneland5090MT:onDeactivateSounds()
    if self.rearMowerSoundEnabled then
        stopSample(self.rearMowerSound);
        self.rearMowerSoundEnabled = false;
    end;
	 if self.sound1Enabled then
        stopSample(self.sound1);
        self.sound1Enabled = false;
    end;
	 if self.sound2Enabled then
        stopSample(self.sound2);
        self.sound2Enabled = false;
    end;
	 if self.sound3Enabled then
        stopSample(self.sound3);
        self.sound3Enabled = false;
    end;
	 if self.sound4Enabled then
        stopSample(self.sound4);
        self.sound4Enabled = false;
    end;
end;
function Kverneland5090MT:setHydraulicDirection()
	for i=1, table.getn(self.hydraulics) do
		local ax, ay, az = getWorldTranslation(self.hydraulics[i].node);
		local bx, by, bz = getWorldTranslation(self.hydraulics[i].fixPoint);
		local x, y, z = worldDirectionToLocal(getParent(self.hydraulics[i].node), bx-ax, by-ay, bz-az);
		
		setDirection(self.hydraulics[i].node, x, y, z, 0, 1, 0);
		local distance = Utils.vector3Length(ax-bx, ay-by, az-bz);
		if self.hydraulics[i].doScale then
			local xScale, yScale, zScale = getScale(self.hydraulics[i].node);
			local newScale = yScale * (distance / self.hydraulics[i].punchDistance);
			setScale(self.hydraulics[i].node, 1, 1, newScale);
		else
			if self.hydraulics[i].punch ~= nil then
				setTranslation(self.hydraulics[i].punch, 0, 0, distance-self.hydraulics[i].punchDistance);
			end;
		end;
	
	end;
end;
function Kverneland5090MT:setJointRotLimit(nodei, up, down, speed, value, axle, dt)

	if not self.firstDo[nodei] then
		self.firstDo[nodei] = true;
		self.arm[nodei] = {0}; 
	end; 
	x, y, z = getRotation(nodei);
	rot = {x,y,z};	
	newRotLimit = {}; 
	newRotLimit[nodei] = {0,0,0};
	newRotLimit[nodei] = Utils.getMovedLimitedValues(self.arm[nodei], {down}, {up}, 1, speed * 2, dt, value);
	if math.abs(newRotLimit[nodei][1] - self.arm[nodei][1]) > 0.001 then
		local joint = nodei;
		setJointRotationLimit(joint.jointIndex, axle, true, Utils.degToRad(-newRotLimit[nodei][1]), Utils.degToRad(newRotLimit[nodei][1]));
	end;
	self.arm[nodei] = newRotLimit[nodei];			
end;

function Kverneland5090MT:anim(varName, loopCheck)	
	-- print("ANIMATION");
	
	self.Activated[varName] = true;
	local loopCheck = self.loopCheck[varName];
	local speed = Utils.getNoNil(self.Speed[varName],1);
	 
	if self.Go[varName] == true and self.Done[varName] ~= false then
		local charId = getAnimCharacterSet(self.charId[varName]);
		local clipIndex = getAnimClipIndex(charId, self.clipIndex[varName]);
		assignAnimTrackClip(charId , 0, clipIndex);
		setAnimTrackLoopState(charId, 0, loopCheck);
		setAnimTrackSpeedScale(charId, 0, speed);
		enableAnimTrack(charId, 0);
		if getAnimTrackTime(charId, 0) >= getAnimClipDuration(charId, clipIndex) and loopCheck == false then
			disableAnimTrack(charId, 0);	
			self.Done[varName] = false;	
			self.CheckDone[varName] = true;	
			self.Activated[varName] = false;
		
			---final animacion hacia delante
		end; 
	elseif self.Go[varName] == false and self.Done[varName] ~= false then
		local charId = getAnimCharacterSet(self.charId[varName]);
		local clipIndex = getAnimClipIndex(charId, self.clipIndex[varName]);
		if loopCheck == true then
			disableAnimTrack(charId, 0);
			self.Done[varName] = false;	
		end; 	
		assignAnimTrackClip(charId , 0, clipIndex);
		setAnimTrackLoopState(charId, 0, loopCheck);
		setAnimTrackSpeedScale(charId, 0, -speed);
		enableAnimTrack(charId, 0);
		if getAnimTrackTime(charId, 0) <= 0 then
			disableAnimTrack(charId, 0);
			self.Done[varName] = false;	
			self.CheckDone[varName] = false;
			self.Activated[varName] = true;
			---final animacion hacia atras
		
		end;
	end;
end; 


function Kverneland5090MT:AllActivated()
	
	if (self.CheckDone["Lift"] == true) and not self.Activated["Lift"]  then
		return true;
	else
		return false;
	end;
	if (self.CheckDone["Suports"] == true) and not self.Activated["Suports"]  then
		return true;
	else
		return false;
	end;
	
end;







